.. Vk documentation master file, created by
   sphinx-quickstart on Tue Mar  3 15:53:30 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Vk's documentation!
==============================

Contents:

.. toctree::
   :maxdepth: 2

   installation
   vk-api
   usage
   customizing


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
